package EPFL::Net::SSLTest;

use 5.006;
use strict;
use warnings;

=head1 NAME

EPFL::Net::SSLTest -  Website SSL accessibility validator

=head1 VERSION

Version 1.00

=cut

our $VERSION = '1.00';

=head1 SYNOPSIS

Nothing to see here for now.

Check the command line epfl-net-ssl-test

=head1 DESCRIPTION

A simple module to validate SSL accessibility of a Website

=head1 SUBROUTINES/METHODS

None

=head1 AUTHOR

William Belle, C<< <william.belle at gmail.com> >>

=head1 BUGS AND LIMITATIONS

Please report any bugs or feature requests here
L<https://github.com/epfl-idevelop/epfl-net-sslTest/issues>.
I will be notified, and then you'll automatically be notified of progress on
your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc EPFL::Net::SSLTest

You can also look for information at:

=over 4

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/EPFL-Net-SSLTest>

=item * CPAN Ratings

L<https://cpanratings.perl.org/d/EPFL-Net-SSLTest>

=item * Search CPAN

L<https://metacpan.org/release/EPFL-Net-SSLTest>

=back

=head1 LICENSE AND COPYRIGHT

Copyright ECOLE POLYTECHNIQUE FEDERALE DE LAUSANNE, Switzerland, VPSI, 2018.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    L<http://www.apache.org/licenses/LICENSE-2.0>

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

=cut

1;
